(* 
 * Copyright (c) 2001 The University of Wroclaw.
 * All rights reserved. See file COPYRIGHT for details about licensing.
 *
 * $Id: gontmodule.mli,v 1.8 2001/11/29 00:29:55 malekith Exp $
 *
 * Module interface: Gontmodule
 * Description: Manage simple Gont module system.
 *)

open Gontutil

(* Save given list of declaration as named module interface to given
 * file. *)
val save : (* module *) string -> out_channel -> decl list -> unit

(* Reset module subsystem state. *)
val reset : unit -> unit

(* Return list of global symbols and types in given module. Used by
 * Gontcodegen to check whatever everything was implemented. *)
val globals : string -> (ty * id) list * typedef list

(* Following functions are only used by Gontbind module. After binding
 * pass, we have symbols assigned in Ref, CrossModuleRef, NamedType and 
 * similar nodes, and we have no reason to use it. *)
 
(* Look for named symbol in named module. *)
val import_symbol : (* module *) string -> (* name *) string -> symbol

(* Look for named type in named module. *)
val import_type_symbol : (* module *) string -> (* name *) string -> typedef

(* Raised whenever given name has no symbol yet. This can happen only
 * before binding. *)
exception Has_no_symbol of ty

(* Used only by Gontbind, when it catches Has_no_symbol exception. Other
 * modules should not use it. *)
val assign_symbol : string -> string -> symbol -> unit

(* Check whatever we can read module interface file, raise Error if not. *)
val open_module : string -> unit
;;
